All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 0/3] meta: 3 minor fixes
@ 2017-03-24  8:55 Robert Yang
  2017-03-24  8:55 ` [PATCH 1/3] runtime-test.py: fix typo Robert Yang
                   ` (2 more replies)
  0 siblings, 3 replies; 6+ messages in thread
From: Robert Yang @ 2017-03-24  8:55 UTC (permalink / raw)
  To: openembedded-core

The following changes since commit 3b5ac72bdf76ac8ff98dc3c882a4edc77c6e2c33:

  rpm: add a "rpm-build" PROVIDES (2017-03-22 15:09:26 +0000)

are available in the git repository at:

  git://git.openembedded.org/openembedded-core-contrib rbt/3fixes
  http://cgit.openembedded.org/openembedded-core-contrib/log/?h=rbt/3fixes

Robert Yang (3):
  runtime-test.py: fix typo
  scripts/wic: fix typo
  apt: fix hardcode of /usr/lib

 meta/lib/oeqa/selftest/runtime-test.py    | 4 ++--
 meta/recipes-devtools/apt/apt-package.inc | 2 +-
 scripts/wic                               | 4 ++--
 3 files changed, 5 insertions(+), 5 deletions(-)

-- 
2.9.0



^ permalink raw reply	[flat|nested] 6+ messages in thread

* [PATCH 1/3] runtime-test.py: fix typo
  2017-03-24  8:55 [PATCH 0/3] meta: 3 minor fixes Robert Yang
@ 2017-03-24  8:55 ` Robert Yang
  2017-03-24  8:55 ` [PATCH 2/3] scripts/wic: " Robert Yang
  2017-03-24  8:55 ` [PATCH 3/3] apt: fix hardcode of /usr/lib Robert Yang
  2 siblings, 0 replies; 6+ messages in thread
From: Robert Yang @ 2017-03-24  8:55 UTC (permalink / raw)
  To: openembedded-core

roofs -> rootfs.

Signed-off-by: Robert Yang <liezhi.yang@windriver.com>
---
 meta/lib/oeqa/selftest/runtime-test.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

-- 
2.9.0



^ permalink raw reply related	[flat|nested] 6+ messages in thread

* [PATCH 2/3] scripts/wic: fix typo
  2017-03-24  8:55 [PATCH 0/3] meta: 3 minor fixes Robert Yang
  2017-03-24  8:55 ` [PATCH 1/3] runtime-test.py: fix typo Robert Yang
@ 2017-03-24  8:55 ` Robert Yang
  2017-03-24  8:55 ` [PATCH 3/3] apt: fix hardcode of /usr/lib Robert Yang
  2 siblings, 0 replies; 6+ messages in thread
From: Robert Yang @ 2017-03-24  8:55 UTC (permalink / raw)
  To: openembedded-core

roofs -> rootfs

Signed-off-by: Robert Yang <liezhi.yang@windriver.com>
---
 scripts/wic | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/scripts/wic b/scripts/wic
index 8e9c05c..a5f2dbf 100755
--- a/scripts/wic
+++ b/scripts/wic
@@ -146,7 +146,7 @@ def wic_create_subcommand(args, usage_str):
         raise WicError("Wrong number of arguments, exiting")
 
     if options.build_rootfs and not bitbake_main:
-        raise WicError("Can't build roofs as bitbake is not in the $PATH")
+        raise WicError("Can't build rootfs as bitbake is not in the $PATH")
 
     if not options.image_name:
         missed = []
@@ -223,7 +223,7 @@ def wic_create_subcommand(args, usage_str):
         kernel_dir = options.kernel_dir
         native_sysroot = options.native_sysroot
         if rootfs_dir and not os.path.isdir(rootfs_dir):
-            raise WicError("--roofs-dir (-r) not found, exiting")
+            raise WicError("--rootfs-dir (-r) not found, exiting")
         if not os.path.isdir(bootimg_dir):
             raise WicError("--bootimg-dir (-b) not found, exiting")
         if not os.path.isdir(kernel_dir):
-- 
2.9.0



^ permalink raw reply related	[flat|nested] 6+ messages in thread

* [PATCH 3/3] apt: fix hardcode of /usr/lib
  2017-03-24  8:55 [PATCH 0/3] meta: 3 minor fixes Robert Yang
  2017-03-24  8:55 ` [PATCH 1/3] runtime-test.py: fix typo Robert Yang
  2017-03-24  8:55 ` [PATCH 2/3] scripts/wic: " Robert Yang
@ 2017-03-24  8:55 ` Robert Yang
  2017-03-24 12:05   ` Burton, Ross
  2 siblings, 1 reply; 6+ messages in thread
From: Robert Yang @ 2017-03-24  8:55 UTC (permalink / raw)
  To: openembedded-core

It should be ${libdir} rather than /usr/lib, otherwise it would fail
when multilib.

Signed-off-by: Robert Yang <liezhi.yang@windriver.com>
---
 meta/recipes-devtools/apt/apt-package.inc | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/meta/recipes-devtools/apt/apt-package.inc b/meta/recipes-devtools/apt/apt-package.inc
index 839d58e..7ebde38 100644
--- a/meta/recipes-devtools/apt/apt-package.inc
+++ b/meta/recipes-devtools/apt/apt-package.inc
@@ -83,7 +83,7 @@ do_install () {
 	install -m 0644 include/apt-pkg/*.h ${D}${includedir}/apt-pkg/
 
 	install -d ${D}${systemd_unitdir}/system/
-	install -m 0644 ${S}/debian/apt.systemd.daily ${D}/usr/lib/apt/
+	install -m 0644 ${S}/debian/apt.systemd.daily ${D}${libdir}/apt/
 	install -m 0644 ${S}/debian/apt-daily.service ${D}${systemd_unitdir}/system/
 	install -m 0644 ${S}/debian/apt-daily.timer ${D}${systemd_unitdir}/system/
 	install -d ${D}${sysconfdir}/cron.daily/
diff --git a/meta/lib/oeqa/selftest/runtime-test.py b/meta/lib/oeqa/selftest/runtime-test.py
index 171a373..ea31c18 100644
--- a/meta/lib/oeqa/selftest/runtime-test.py
+++ b/meta/lib/oeqa/selftest/runtime-test.py
@@ -181,10 +181,10 @@ postinst-delayed-t \
                         break
 
     @testcase(1545)
-    def test_postinst_roofs_and_boot(self):
+    def test_postinst_rootfs_and_boot(self):
         """
         Summary:        The purpose of this test case is to verify Post-installation
                         scripts are called when roofs is created and also test
                         that script can be delayed to run at first boot.
         Dependencies:   NA
         Steps:          1. Add proper configuration to local.conf file
@@ -181,10 +181,10 @@ postinst-delayed-t \
         """
         Summary:        The purpose of this test case is to verify Post-installation
-                        scripts are called when roofs is created and also test
+                        scripts are called when rootfs is created and also test
                         that script can be delayed to run at first boot.
         Dependencies:   NA
-- 
2.9.0



^ permalink raw reply related	[flat|nested] 6+ messages in thread

* Re: [PATCH 3/3] apt: fix hardcode of /usr/lib
  2017-03-24  8:55 ` [PATCH 3/3] apt: fix hardcode of /usr/lib Robert Yang
@ 2017-03-24 12:05   ` Burton, Ross
  2017-03-27  1:47     ` Robert Yang
  0 siblings, 1 reply; 6+ messages in thread
From: Burton, Ross @ 2017-03-24 12:05 UTC (permalink / raw)
  To: Robert Yang; +Cc: OE-core

[-- Attachment #1: Type: text/plain, Size: 504 bytes --]

On 24 March 2017 at 08:55, Robert Yang <liezhi.yang@windriver.com> wrote:

> -       install -m 0644 ${S}/debian/apt.systemd.daily ${D}/usr/lib/apt/
> +       install -m 0644 ${S}/debian/apt.systemd.daily ${D}${libdir}/apt/
>

$ grep -r apt.systemd.daily
debian/apt-daily.service:ExecStart=/usr/lib/apt/apt.systemd.daily
debian/apt.apt-compat.cron.daily:exec /usr/lib/apt/apt.systemd.daily

If you're going to move apt.systemd.daily, then you need to fix the
references to it aswell.

Ross

[-- Attachment #2: Type: text/html, Size: 1169 bytes --]

^ permalink raw reply	[flat|nested] 6+ messages in thread

* Re: [PATCH 3/3] apt: fix hardcode of /usr/lib
  2017-03-24 12:05   ` Burton, Ross
@ 2017-03-27  1:47     ` Robert Yang
  0 siblings, 0 replies; 6+ messages in thread
From: Robert Yang @ 2017-03-27  1:47 UTC (permalink / raw)
  To: Burton, Ross; +Cc: OE-core



On 03/24/2017 08:05 PM, Burton, Ross wrote:
>
> On 24 March 2017 at 08:55, Robert Yang <liezhi.yang@windriver.com
> <mailto:liezhi.yang@windriver.com>> wrote:
>
>     -       install -m 0644 ${S}/debian/apt.systemd.daily ${D}/usr/lib/apt/
>     +       install -m 0644 ${S}/debian/apt.systemd.daily ${D}${libdir}/apt/
>
>
> $ grep -r apt.systemd.daily
> debian/apt-daily.service:ExecStart=/usr/lib/apt/apt.systemd.daily
> debian/apt.apt-compat.cron.daily:exec /usr/lib/apt/apt.systemd.daily
>
> If you're going to move apt.systemd.daily, then you need to fix the references
> to it aswell.

Thanks, I will send apt's fix in another path since the other 2 patches are
in master-next.

// Robert

>
> Ross


^ permalink raw reply	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2017-03-27  1:47 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2017-03-24  8:55 [PATCH 0/3] meta: 3 minor fixes Robert Yang
2017-03-24  8:55 ` [PATCH 1/3] runtime-test.py: fix typo Robert Yang
2017-03-24  8:55 ` [PATCH 2/3] scripts/wic: " Robert Yang
2017-03-24  8:55 ` [PATCH 3/3] apt: fix hardcode of /usr/lib Robert Yang
2017-03-24 12:05   ` Burton, Ross
2017-03-27  1:47     ` Robert Yang

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.